==> com.liferay.headless.commerce.admin.catalog.impl-4.0.88-sources-commercial.jar: com/liferay/headless/commerce/admin/catalog/internal/jaxrs/exception/mapper/ProductDeliverySubscriptionLengthExceptionMapper.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.headless.commerce.admin.catalog.internal.jaxrs.exception.mapper;

import com.liferay.commerce.product.exception.CPDefinitionDeliverySubscriptionLengthException;
import com.liferay.portal.vulcan.jaxrs.exception.mapper.BaseExceptionMapper;
import com.liferay.portal.vulcan.jaxrs.exception.mapper.Problem;

import javax.ws.rs.core.Response;
import javax.ws.rs.ext.ExceptionMapper;

import org.osgi.service.component.annotations.Component;

/**
 * @author Crescenzo Rega
 */
@Component(
	property = {
		"osgi.jaxrs.application.select=(osgi.jaxrs.name=Liferay.Headless.Commerce.Admin.Catalog)",
		"osgi.jaxrs.extension=true",
		"osgi.jaxrs.name=Liferay.Headless.Commerce.Admin.Catalog.ProductDeliverySubscriptionLengthExceptionMapper"
	},
	service = ExceptionMapper.class
)
public class ProductDeliverySubscriptionLengthExceptionMapper
	extends BaseExceptionMapper
		<CPDefinitionDeliverySubscriptionLengthException> {

	@Override
	protected Problem getProblem(
		CPDefinitionDeliverySubscriptionLengthException
			cpDefinitionDeliverySubscriptionLengthException) {

		return new Problem(
			Response.Status.BAD_REQUEST,
			cpDefinitionDeliverySubscriptionLengthException.getMessage());
	}

}

==> com.liferay.headless.commerce.admin.catalog.impl-4.0.91-sources-commercial.jar: com/liferay/headless/commerce/admin/catalog/internal/jaxrs/exception/mapper/ProductDeliverySubscriptionLengthExceptionMapper.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.headless.commerce.admin.catalog.internal.jaxrs.exception.mapper;

import com.liferay.commerce.product.exception.CPDefinitionDeliverySubscriptionLengthException;
import com.liferay.portal.vulcan.jaxrs.exception.mapper.BaseExceptionMapper;
import com.liferay.portal.vulcan.jaxrs.exception.mapper.Problem;

import javax.ws.rs.ext.ExceptionMapper;

import org.osgi.service.component.annotations.Component;

/**
 * @author Crescenzo Rega
 */
@Component(
	property = {
		"osgi.jaxrs.application.select=(osgi.jaxrs.name=Liferay.Headless.Commerce.Admin.Catalog)",
		"osgi.jaxrs.extension=true",
		"osgi.jaxrs.name=Liferay.Headless.Commerce.Admin.Catalog.ProductDeliverySubscriptionLengthExceptionMapper"
	},
	service = ExceptionMapper.class
)
public class ProductDeliverySubscriptionLengthExceptionMapper
	extends BaseExceptionMapper
		<CPDefinitionDeliverySubscriptionLengthException> {

	@Override
	protected Problem getProblem(
		CPDefinitionDeliverySubscriptionLengthException
			cpDefinitionDeliverySubscriptionLengthException) {

		return new Problem(cpDefinitionDeliverySubscriptionLengthException);
	}

}
